@@ -9,7 +9,7 @@ use utf8;
 use Data::Dumper;
 use JSON qw();
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 sub MAX_RECURSION () {300}
 
@@ -324,9 +324,9 @@ App::yajg - yet another json grep
 
 =head1 SYNOPSIS
 
-B<yajg> [B<-chimquvz>]
+B<yajg> [B<-cEhimquvz>]
 [B<-p> F<key_pattern>] [B<-P> F<value_pattern>] [B<-s> F<select_path>] [B<-S> F<select_path>]
-[B<-o> F<output_format>] [B<-b> F<boolean_type>] [B<-d> F<depth>]
+[B<-o> F<output_format>] [B<-b> F<boolean_type>] [B<-d> F<depth>] [B<--sort-keys>]
 [B<-e> F<code>]
 [F<files>]
 
@@ -458,8 +458,7 @@ Convert boolean types to defined format:
 
 Maby usefull because by default all C<true> is ref to
 C<Types::Serialiser::true> and all C<false> is ref to
-C<Types::Serialiser::false> and the output in the B<perl>, the B<ddp> or the
-B<yaml> format looks very ugly.
+C<Types::Serialiser::false> and the output in some formats can be hard to read
 
 =item B<-c, --color, --no-color>
 
@@ -475,9 +474,26 @@ files.
 
 How deep to traverse the data (0 for all)
 
+B<WARNING> when the json booleans has same level as the --max-depth then they
+will be converted to string C<0>, C<1> or C<true>, C<false> (depends on JSON
+version)
+
+B<WARNING> can change number type to string.
+
 =item B<-m, --minimal>
 
-Minimize output. Supported only by B<json> and B<perl> output types.
+Minimize output. Does not supported by the B<yaml> output.
+
+=item B<--sort-keys, --no-sort-keys>
+
+Enable/disable sorting hash keys. By default enabled when the L</-m, --minimal>
+option is disabled.
+
+=item B<-E, --escapes, --no-escapes>
+
+Print non-printable chars as "\n", "\t", etc. By default enabled when the
+L</-m, --minimal> option is enabled. For B<json> output always enabled (JSON
+format requires to escape this chars)
 
 =item B<-q, --quiet>
 
