@@ -8,30 +8,22 @@ use strict;
 use warnings;
 use utf8;
 
-use Scalar::Util 'blessed';
-
-sub _is_bool ($) {
-    blessed $_[0] and (
-        $_[0]->isa('Types::Serialiser::BooleanBase')
-        or $_[0]->isa('JSON::PP::Boolean')
-        or $_[0]->isa('JSON::XS::Boolean')
-      )
-}
+use JSON qw();
 
 sub boolean_to_scalar_ref {
-    return unless _is_bool $_[0];
+    return unless JSON::is_bool($_[0]);
     $_[0] = $_[0]
       ? \(my $t = 1)
       : \(my $f = 0);
 }
 
 sub boolean_to_int {
-    return unless _is_bool $_[0];
+    return unless JSON::is_bool($_[0]);
     $_[0] = int(!!$_[0]);
 }
 
 sub boolean_to_str {
-    return unless _is_bool $_[0];
+    return unless JSON::is_bool($_[0]);
     $_[0] = $_[0]
       ? 'true'
       : 'false';
