@@ -15,9 +15,13 @@ sub need_change_depth {0}    # need to change max depth via Data::Dumper
 sub as_string {
     my $self = shift;
     return Data::Printer::np($self->data,
-        colored   => $self->color,
-        max_depth => $self->max_depth,
-    ) . "\n";
+        colored        => $self->color,
+        max_depth      => $self->max_depth,
+        multiline      => (not $self->minimal),
+        sort_keys      => $self->sort_keys,
+        print_escapes  => $self->escapes,
+        hash_separator => ' => ',
+    );
 }
 
 1;
