@@ -19,9 +19,9 @@ sub as_string {
     my $json = eval {
         JSON
           ->new
-          ->pretty(int not $self->minimal)
+          ->pretty(not $self->minimal)
+          ->canonical($self->sort_keys // 0)
           ->allow_nonref
-          ->canonical
           ->encode($self->data)
     };
     if ($@) {
