@@ -15,6 +15,8 @@ sub need_change_depth {1}    # need to change max depth via Data::Dumper
 
 sub as_string {
     my $self = shift;
+    local $YAML::SortKeys = $self->sort_keys;
+    local $YAML::UseBlock = not $self->escapes;
     return YAML::Dump($self->data);
 }
 
